These functions are provided for compatibility with older versions of vcdExtra and will be removed in a future release.
Details
Summarise()is deprecated in favor ofLRstats(), which provides the same brief model-fit comparison under a name that doesn't near-collide withdplyr::summarise().