vcdExtra-deprecated: Deprecated functions in vcdExtra
Description
These functions are provided for compatibility with older versions of
vcdExtra and will be removed in a future release.
Arguments
Details
Summarise() is deprecated in favor of LRstats(), which provides
the same brief model-fit comparison under a name that doesn't
near-collide with dplyr::summarise().